aboutsummaryrefslogtreecommitdiff
path: root/bdep/release.cxx
diff options
context:
space:
mode:
Diffstat (limited to 'bdep/release.cxx')
-rw-r--r--bdep/release.cxx4
1 files changed, 2 insertions, 2 deletions
diff --git a/bdep/release.cxx b/bdep/release.cxx
index 71c6372..00c8dca 100644
--- a/bdep/release.cxx
+++ b/bdep/release.cxx
@@ -680,11 +680,11 @@ namespace bdep
standard_version v;
try
{
// Allow stubs only in the --revision mode.
//
standard_version::flags f (standard_version::none);
- if (o.revision ())
+ if (o.revision () || o.tag ())
f |= standard_version::allow_stub;
v = standard_version (vv.value, f);
@@ -680,11 +680,11 @@ namespace bdep
try
{
- // Allow stubs only in the --revision mode.
+ // Allow stubs only in the --revision and --tag modes.
//
standard_version::flags f (standard_version::none);